@@ -826,7 +826,7 @@ void *hunt(void *arg)
 					ALIGNPOINTERS_TCP(iph, p->p_hdr.p_tcph,
 							  p->p_data);
 					p->p_data_len = TCP_DATA_LENGTH(iph, p->p_hdr.p_tcph);
-					if (ip_in_cksum(iph, (unsigned short *) p->p_hdr.p_tcph, 
+					if (ip_in_cksum(iph, (unsigned short *) p->p_hdr.p_tcph,
 					    IP_DATA_LENGTH(iph)) == 0) {
 						conn_update_table(p, ethh, iph);
 						fast_tcp_process(p);
@@ -895,12 +895,12 @@ cont:
  * helper functions
  * 
  */
-void print_tcp(struct iphdr *ip, struct tcphdr *tcp)
+void print_tcp(struct packet *p, struct iphdr *ip, struct tcphdr *tcp)
 {
-       fprintf(stdout, "%s [%d] seq=(%u) ack=(%u)\t--->\t%s [%d]\n",
+       fprintf(stdout, "%s [%d] seq=(%u) ack=(%u)\t--->\t%s [%d] len=%d/%d\n",
 	       host_lookup(ip->saddr, hl_mode), ntohs(tcp->source), 
 	       (unsigned int) ntohl(tcp->seq), tcp->ack ? (unsigned int) ntohl(tcp->ack_seq) : 0,
-	       host_lookup(ip->daddr, hl_mode), ntohs(tcp->dest));
+	       host_lookup(ip->daddr, hl_mode), ntohs(tcp->dest), p->p_raw_len, p->p_data_len);
 }
 
 static int fill_space_to(char *b, int pos, int where)
