@@ -46,7 +46,7 @@
 #include "c/list.h"
 #include "c/hash.h"
 
-#define VERSION	"1.4"
+#define VERSION	"1.5"
 
 #define max(a, b)	((a) > (b) ? (a) : (b))
 #define min(a, b)	((a) > (b) ? (b) : (a))
@@ -578,6 +578,7 @@ int tty_cbreak(int fd, int wait_for_chars, int timer_dsec);
 int tty_raw(int fd, int wait_for_chars, int timer_dsec);
 int tty_reset(int fd);
 void tty_atexit(void);
+void tty_tput_reset(void);
 
 /*
  * addpolicy.c
@@ -596,6 +597,7 @@ void addpolicy_del_item(void);
  * options.c
  */
 extern int lines_o;
+extern int print_cntrl_chars;
 
 void options_menu(void);
 void lines_o_press_key();
